==> gromacs_2021.4.orig.tar.gz: gromacs-2021.4/src/gromacs/gpu_utils/tests/typecasts_runner.cpp <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 2020, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*! \internal \file
 * \brief
 * Stub for runners for tests types compatibility.
 *
 * \author Artem Zhmurov <zhmurov@gmail.com>
 */
#include "gmxpre.h"

#include "typecasts_runner.h"

#include "config.h"

#include <vector>

#include "testutils/testasserts.h"

#if !GMX_GPU_CUDA

namespace gmx
{

namespace test
{

void convertRVecToFloat3OnHost(std::vector<gmx::RVec>& /* rVecOutput */,
                               const std::vector<gmx::RVec>& /* rVecInput */)
{
    FAIL() << "Can't test float3 and RVec compatibility without CUDA.";
}

void convertRVecToFloat3OnDevice(std::vector<gmx::RVec>& /* rVecOutput */,
                                 const std::vector<gmx::RVec>& /* rVecInput */,
                                 const TestDevice* /* testDevice */)
{
    FAIL() << "Can't test float3 and RVec compatibility without CUDA.";
}

} // namespace test
} // namespace gmx

#endif // !GMX_GPU_CUDA

==> gromacs-2023.5.tar.gz: gromacs-2023.5/src/gromacs/gpu_utils/tests/typecasts_runner.cpp <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright 2020- The GROMACS Authors
 * and the project initiators Erik Lindahl, Berk Hess and David van der Spoel.
 * Consult the AUTHORS/COPYING files and https://www.gromacs.org for details.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * https://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at https://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out https://www.gromacs.org.
 */
/*! \internal \file
 * \brief
 * Stub for runners for tests types compatibility.
 *
 * \author Artem Zhmurov <zhmurov@gmail.com>
 */
#include "gmxpre.h"

#include "typecasts_runner.h"

#include "config.h"

#include <vector>

#include "gromacs/utility/arrayref.h"

#include "testutils/testasserts.h"

#if !GMX_GPU_CUDA

namespace gmx
{

namespace test
{

void convertRVecToFloat3OnHost(ArrayRef<gmx::RVec> /* rVecOutput */,
                               ArrayRef<const gmx::RVec> /* rVecInput */)
{
    FAIL() << "Can't test float3 and RVec compatibility without CUDA.";
}

void convertRVecToFloat3OnDevice(ArrayRef<gmx::RVec> /* rVecOutput */,
                                 ArrayRef<const gmx::RVec> /* rVecInput */,
                                 const TestDevice* /* testDevice */)
{
    FAIL() << "Can't test float3 and RVec compatibility without CUDA.";
}

} // namespace test
} // namespace gmx

#endif // !GMX_GPU_CUDA
